@@ -138,7 +138,7 @@ class FakeClient(test_utils.FakeClient):
             if not pp:
                 raise client_exceptions.NotFound()
             if pp['portpairgroup_id']:
-                    raise client_exceptions.Conflict(constants.STR_IN_USE)
+                raise client_exceptions.Conflict(constants.STR_IN_USE)
         elif _type == constants.RT_FLOW_CLASSIFIER:
             pc_list = self._res_map[self.region_name][constants.RT_PORT_CHAIN]
             for pc in pc_list:
@@ -406,6 +406,7 @@ class PluginTest(unittest.TestCase):
     def setUp(self):
         core.initialize()
         core.ModelBase.metadata.create_all(core.get_engine())
+        cfg.CONF.register_opts(q_config.core_opts)
         core.get_engine().execute('pragma foreign_keys=on')
         self.context = context.Context()
         xmanager.IN_TEST = True
@@ -1010,6 +1011,7 @@ class PluginTest(unittest.TestCase):
             'port_pairs': [t_pp1_id, t_pp2_id]}}
         ppg_mapping = {t_pp2_id: t_ppg1_id}
         self._update_port_pair_test(ppg_mapping, TOP_PORTPAIRS)
+
         fake_sfc_plugin.update_port_pair_group(q_ctx, t_ppg1_id, ppg_body)
         self.assertEqual(TOP_PORTPAIRGROUPS[0]['name'], 'new_name')
         self.assertEqual(TOP_PORTPAIRGROUPS[0]['description'],
@@ -1021,7 +1023,6 @@ class PluginTest(unittest.TestCase):
                          'new_ppg_description')
         self.assertEqual(BOTTOM1_PORTPAIRGROUPS[0]['port_pairs'],
                          [b_pp1_id, b_pp2_id])
-
         t_ppg2_id, b_ppg2_id = self._prepare_port_pair_group_test(
             project_id, t_ctx, 'pod_1', 0,
             [], True, [])
