@@ -241,6 +241,7 @@ class PluginTest(unittest.TestCase):
     def setUp(self):
         core.initialize()
         core.ModelBase.metadata.create_all(core.get_engine())
+        cfg.CONF.register_opts(q_config.core_opts)
         self.context = context.Context()
         cfg.CONF.set_override('tenant_network_types', ['local', 'vlan'],
                               group='tricircle')
@@ -298,8 +299,6 @@ class PluginTest(unittest.TestCase):
                 'id': t_port_id,
                 'name': t_port_id,
                 'description': 'old_bottom_description',
-                'extra_dhcp_opts': [],
-                'device_owner': device_onwer,
                 'security_groups': [],
                 'device_id': '68f46ee4-d66a-4c39-bb34-ac2e5eb85470',
                 'admin_state_up': True,
@@ -570,8 +569,8 @@ class PluginTest(unittest.TestCase):
                   new=fake_get_context_from_neutron_context)
     def test_action_subports(self):
         project_id = TEST_TENANT_ID
-        q_ctx = FakeNeutronContext()
         t_ctx = context.get_db_context()
+        q_ctx = FakeNeutronContext()
         self._basic_pod_setup()
         fake_plugin = FakePlugin()
 
